#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: file-embed
version: 0.0.10
id: file-embed-0.0.10-c7da10dfba0f55c7c135317c0bfb8508
key: filee_BNyHeBYneTRAp0kIbc1T1P
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/snoyberg/file-embed
synopsis: Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your haskell code.
category: Data
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Data.FileEmbed
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/file-embed-0.0.10
library-dirs: /usr/lib/ghc-7.10.3/site-local/file-embed-0.0.10
data-dir: /usr/share/arm-linux-ghc-7.10.3/file-embed-0.0.10
hs-libraries: HSfile-embed-0.0.10-BNyHeBYneTRAp0kIbc1T1P
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
haddock-interfaces: /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html: /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
